@@ -1,6 +1,6 @@
 package Bundle::ABH;
 
-$VERSION = "1.02";
+$VERSION = "1.03";
 #$VERSION = sprintf("%d.%02d", q$Revision: 1.0 $ =~ /(\d+)\.(\d+)/);   
 
 1;
@@ -87,6 +87,12 @@ Set::IntRange
 
 XML::Parser
 
+Date::Calc
+
+Number::Format
+
+Event
+
 =head1 DESCRIPTION
 
 This bundle defines most of the modules Ask Bjoern Hansen usually
